@@ -84,6 +84,19 @@ class SchemaEndpoint(RestEndpoint):
                         "category": effect.CATEGORY,
                     }
 
+                    if effect.HIDDEN_KEYS:
+                        response["effects"][effect_type][
+                            "hidden_keys"
+                        ] = effect.HIDDEN_KEYS
+                    if effect.ADVANCED_KEYS:
+                        response["effects"][effect_type][
+                            "advanced_keys"
+                        ] = effect.ADVANCED_KEYS
+                    if effect.PERMITTED_KEYS:
+                        response["effects"][effect_type][
+                            "permitted_keys"
+                        ] = effect.PERMITTED_KEYS
+
             elif schema == "integrations":
                 # Generate all the integrations schema
                 response["integrations"] = {}
