@@ -28,6 +28,21 @@ _default_wled_settings = {
 }
 
 
+# Transmission types for pixel visualisation on frontend
+class Transmission:
+    BASE64_COMPRESSED = "compressed"
+    UNCOMPRESSED = "uncompressed"
+
+    @staticmethod
+    def get_list():
+        transmission_dict = vars(Transmission)
+        t_list = []
+        for attribute in transmission_dict.keys():
+            if attribute[:2] != "__" and attribute != "get_list":
+                t_list.append(getattr(Transmission, attribute))
+        return t_list
+
+
 # adds the {setting: ..., user: ...} thing to the defaults dict
 def parse_default_wled_setting(setting):
     key, value = setting
@@ -77,11 +92,14 @@ CORE_CONFIG_SCHEMA = vol.Schema(
         vol.Optional("user_presets", default={}): dict,
         vol.Optional("scenes", default={}): dict,
         vol.Optional("integrations", default=[]): list,
+        vol.Optional("transmission_mode", default="compressed"): vol.In(
+            Transmission.get_list()
+        ),
         vol.Optional("visualisation_fps", default=30): vol.All(
             int, vol.Range(1, 60)
         ),
         vol.Optional("visualisation_maxlen", default=81): vol.All(
-            int, vol.Range(5, 300)
+            int, vol.Range(5, 4096)
         ),
         vol.Optional(
             "global_transitions",
