@@ -1,4 +1,114 @@
 ledfx_presets = {
+    "plasma2d": {
+        "reset": {
+            "config": {
+                "advanced": False,
+                "background_brightness": 1.0,
+                "background_color": "#000000",
+                "blur": 0.0,
+                "brightness": 1.0,
+                "density": 0.7,
+                "diag": False,
+                "dump": False,
+                "flip": False,
+                "flip horizontal": False,
+                "flip vertical": False,
+                "frequency_range": "Lows (beat+bass)",
+                "gradient": "linear-gradient(90deg, #ff0000 0.00%,#ff7800 14.00%,#ffc800 28.00%,#00ff00 42.00%,#00c78c 56.00%,#0000ff 70.00%,#800080 84.00%,#ff00b2 98.00%)",
+                "gradient_roll": 0.0,
+                "lower": 0.57,
+                "mirror": False,
+                "radius": 0.2,
+                "rotate": 0,
+                "test": False,
+                "twist": 0.07,
+                "v density": 0.1,
+            },
+            "name": "Reset",
+        },
+        "aprilnight": {
+            "config": {
+                "advanced": False,
+                "background_brightness": 1.0,
+                "background_color": "#000000",
+                "blur": 0.0,
+                "brightness": 1.0,
+                "density": 0.7,
+                "diag": False,
+                "dump": False,
+                "flip": False,
+                "flip horizontal": False,
+                "flip vertical": False,
+                "frequency_range": "Bass",
+                "gradient": "linear-gradient(90deg, #000000 0.00%,#000000 3.00%,#05a9af 9.00%,#000000 15.00%,#000000 23.00%,#2daf1f 29.00%,#000000 35.00%,#000000 43.00%,#f99605 49.00%,#000000 56.00%,#000000 63.00%,#ff5c00 69.00%,#000000 75.00%,#000000 83.00%,#df2d48 89.00%,#000000 95.00%,#000000 100.00%)",
+                "gradient_roll": 0.0,
+                "lower": 0.83,
+                "mirror": False,
+                "radius": 0.2,
+                "rotate": 0,
+                "test": False,
+                "twist": 0.07,
+                "v density": 0.1,
+            },
+            "name": "AprilNight",
+        },
+    },
+    "plasmawled": {
+        "reset": {
+            "config": {
+                "advanced": False,
+                "background_brightness": 1.0,
+                "background_color": "#000000",
+                "blur": 0.0,
+                "brightness": 1.0,
+                "diag": False,
+                "dump": False,
+                "flip": False,
+                "flip horizontal": False,
+                "flip vertical": False,
+                "frequency_range": "Lows (beat+bass)",
+                "gradient": "linear-gradient(90deg, #ff0000 0.00%,#ff7800 14.00%,#ffc800 28.00%,#00ff00 42.00%,#00c78c 56.00%,#0000ff 70.00%,#800080 84.00%,#ff00b2 98.00%)",
+                "gradient_roll": 0.0,
+                "h_stretch": 128,
+                "mirror": False,
+                "multiplier": 1.0,
+                "rotate": 0,
+                "size x": 0.4,
+                "speed": 128,
+                "speed x": 0.4,
+                "test": False,
+                "v_stretch": 128,
+            },
+            "name": "Reset",
+        },
+        "snowcrash": {
+            "config": {
+                "advanced": False,
+                "background_brightness": 1.0,
+                "background_color": "#000000",
+                "blur": 0.0,
+                "brightness": 1.0,
+                "diag": False,
+                "dump": False,
+                "flip": False,
+                "flip horizontal": False,
+                "flip vertical": False,
+                "frequency_range": "Lows (beat+bass)",
+                "gradient": "linear-gradient(90deg, #000000 1.00%,#ffffff 100.00%)",
+                "gradient_roll": 0.0,
+                "h_stretch": 28,
+                "mirror": False,
+                "multiplier": 0.83,
+                "rotate": 0,
+                "size x": 0.7,
+                "speed": 28,
+                "speed x": 0.0,
+                "test": False,
+                "v_stretch": 30,
+            },
+            "name": "Snow Crash",
+        },
+    },
     "bar": {
         "reset": {
             "config": {
@@ -1690,6 +1800,28 @@ ledfx_presets = {
             },
             "name": "Ocean Bass",
         },
+        "purplered-bass": {
+            "config": {
+                "blur": 2,
+                "flip": False,
+                "color": "#00ffff",
+                "decay": 0.7,
+                "mirror": False,
+                "gradient": "#ff00b2",
+                "brightness": 1,
+                "multiplier": 0.5,
+                "invert_roll": False,
+                "solid_color": False,
+                "gradient_name": "Ocean",
+                "gradient_roll": 0,
+                "frequency_range": "Lows (beat+bass)",
+                "gradient_repeat": 1,
+                "background_color": "#ff0000",
+                "color_correction": True,
+                "background_brightness": 0.1,
+            },
+            "name": "PurpleRed Bass",
+        },
     },
     "bands": {
         "reset": {
@@ -2027,6 +2159,21 @@ ledfx_presets = {
                 "speed": 0.2,
             },
         },
+        "purple-red": {
+            "name": "Purple Red",
+            "config": {
+                "blur": 0,
+                "flip": False,
+                "speed": 0.2,
+                "mirror": False,
+                "gradient": "linear-gradient(90deg, #ff00b2 0.00%,#ffa500 50.00%,#ffc800 100.00%)",
+                "brightness": 1,
+                "reactivity": 0.3,
+                "gradient_roll": 0,
+                "background_color": "#ff0000",
+                "background_brightness": 0.3,
+            },
+        },
     },
     "pitchSpectrum": {
         "reset": {
