@@ -5,6 +5,8 @@
 /* eslint-disable global-require */
 /* eslint-disable @typescript-eslint/no-var-requires */
 const path = require('path');
+const Store = require('electron-store');
+const store = new Store();
 
 const {
   app,
@@ -20,6 +22,11 @@ const {
 const isDev = require('electron-is-dev');
 // const { download } = require('electron-dl');
 const fs = require('fs');
+const crypto = require('crypto');
+const base32Encode = require('base32-encode');
+const qrcode = require('qrcode');
+
+require('events').EventEmitter.defaultMaxListeners = 15;
 
 // Conditionally include the dev tools installer to load React Dev Tools
 let installExtension;
@@ -33,6 +40,49 @@ if (require('electron-squirrel-startup')) {
   app.quit();
 }
 
+const base32Decode = require('base32-decode')
+
+function generateHOTP(secret, counter) {
+  const decodedSecret = base32Decode(secret, 'RFC4648');
+
+  const buffer = Buffer.alloc(8);
+  for (let i = 0; i < 8; i++) {
+    buffer[7 - i] = counter & 0xff;
+    counter = counter >> 8;
+  }
+
+  // Step 1: Generate an HMAC-SHA-1 value
+  const hmac = crypto.createHmac('sha1', Buffer.from(decodedSecret));
+  hmac.update(buffer);
+  const hmacResult = hmac.digest();
+
+  // Step 2: Generate a 4-byte string (Dynamic Truncation)
+  const offset = hmacResult[hmacResult.length - 1] & 0xf;
+  const code =
+    ((hmacResult[offset] & 0x7f) << 24) |
+    ((hmacResult[offset + 1] & 0xff) << 16) |
+    ((hmacResult[offset + 2] & 0xff) << 8) |
+    (hmacResult[offset + 3] & 0xff);
+
+  // Step 3: Compute an HOTP value
+  return `${code % 10 ** 6}`.padStart(6, '0');
+}
+
+function generateTOTP(secret, window = 0) {
+  const counter = Math.floor(Date.now() / 30000);
+  return generateHOTP(secret, counter + window);
+}
+
+function verifyTOTP(token, secret, window = 1) {
+  for (let errorWindow = -window; errorWindow <= +window; errorWindow++) {
+    const totp = generateTOTP(secret, errorWindow);
+    if (token === totp) {
+      return true;
+    }
+  }
+  return false;
+}
+
 let win;
 
 function createWindow(args = {}) {
@@ -236,8 +286,58 @@ const ready = () => (
       return { action: 'allow' }
     })
 
-    ipcMain.on('toMain', (event, parameters) => {
-      console.log(parameters);
+    ipcMain.on('toMain', async (event, parameters) => {
+      console.log('ALL PARAMS', parameters);
+      if (parameters.command === 'verify_otp') {
+        const user = store.get('user') || {
+          username: 'FreeUser',
+          mfaEnabled: false,
+          mfaSecret: null
+        }
+        const token = parameters.token;
+        const secret = user.mfaSecret;
+        console.log('verify_otp:', user)
+        const verified = verifyTOTP(token, secret);
+        if (verified) {
+          user.mfaEnabled = true;
+          store.set('user', user);
+        }
+
+        console.log('verified_otp:', verified ,user)
+        wind.webContents.send('fromMain', ['mfa-verified', verified]);
+        return;
+      }
+      if (parameters.command === 'generate-mfa-qr') {
+        const user = store.get('user') || {
+          username: 'FreeUser',
+          mfaEnabled: false,
+          mfaSecret: null
+        };
+        console.log('generate-mfa-qr:', user)
+        // For security, we no longer show the QR code after is verified
+        if (user.mfaEnabled) return;
+
+        if (!user.mfaSecret) {
+          // generate unique secret for user
+          // this secret will be used to check the verification code sent by user
+          const buffer = crypto.randomBytes(14);
+          user.mfaSecret = base32Encode(buffer, 'RFC4648', { padding: false });
+          console.log('generated-mfa-qr', user);
+          store.set('user', user);
+        }
+        const issuer = 'Blade\'s LedFx';
+        const algorithm = 'SHA1';
+        const digits = '6';
+        const period = '30';
+        const otpType = 'totp';
+        const configUri = `otpauth://${otpType}/${issuer}:${user.username}?algorithm=${algorithm}&digits=${digits}&period=${period}&issuer=${issuer}&secret=${user.mfaSecret}`;
+
+        qrcode.toDataURL(configUri, {
+          color: { dark: '#333333FF', light: '#00000000' },
+        }).then((png=>wind.webContents.send('fromMain', ['mfa-qr-code', png])));
+
+        return;
+      }
       if (parameters === 'get-platform') {
         wind.webContents.send('fromMain', ['platform', process.platform]);
         return;
@@ -267,25 +367,6 @@ const ready = () => (
         app.exit();
         return;
       }
-      // if (parameters === 'download-core') {
-      //   download(
-      //     wind,
-      //     `https://github.com/YeonV/LedFx-Frontend-v2/releases/latest/download/LedFx_core-${
-      //       app.getVersion().split('-')[1]
-      //     }--win-portable.exe`,
-      //     {
-      //       directory: thePath,
-      //       overwrite: true,
-      //       onProgress: (obj) => {
-      //         wind.webContents.send('fromMain', ['download-progress', obj]);
-      //       },
-      //     }
-      //   ).then(() => {
-      //     wind.webContents.send('fromMain', 'clear-frontend');
-      //     app.relaunch();
-      //     app.exit();
-      //   });
-      // }
     });
 
     wind.on('close', function(e){
